# PyPlugs

_Decorator based plug-in architecture for Python_

[![Latest version](https://img.shields.io/pypi/v/pyplugs.svg)](https://pypi.org/project/pyplugs/)
[![Python versions](https://img.shields.io/pypi/pyversions/pyplugs.svg)](https://pypi.org/project/pyplugs/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)


## Installing PyPlugs

PyPlugs is available at [PyPI](https://pypi.org/project/pyplugs/). You can install it using Pip:

    $ python -m pip install pyplugs


## Using PyPlugs

...


## Installing From Source

You can always download the [latest version of PyPlugs from GitHub](https://github.com/gahjelle/pyplugs). PyPlugs uses [Flit](https://flit.readthedocs.io/) as a setup tool.

To install PyPlugs from the downloaded source, run Flit:

    $ python -m flit install --deps production

If you want to change and play with the PyPlugs source code, you should install it in editable mode:

    $ python -m flit install --symlink